@@ -30,8 +30,10 @@ int  main (int argc, char *argv[]) {
     cerr << "Error: " << er.error << " " << con.errnum() << endl;
 #endif
     return -1;
+#ifdef USE_STANDARD_EXCEPTION		
 	} catch (exception &er) {
     cerr << "Error: " << er.what() << endl;
     return -1;
+#endif		
         }
 }
